from apitax.drivers.Driver import Driver
from apitax.utilities.Files import getAllFiles
from apitax.ah.Options import Options
from pathlib import Path
from apitax.ah.Credentials import Credentials


class AnsibleDriver(Driver):
    def isApiAuthenticated(self):
        return False

    def isTokenable(self):
        return False
